@@ -474,7 +474,12 @@ SwFrmFmt *SwDoc::CopyLayoutFmt( const SwFrmFmt& rSource,
 
         // sorge dafuer das auch Fly's in Fly's kopiert werden
         aIdx = *pSttNd->EndOfSectionNode();
+        bool bDrawingLayerUndoState = GetIDocumentUndoRedo().DoesDrawUndo();
+        //fdo#36631 disable any undo operations associated with the contact
+        //object itself. They should be managed by SwUndoInsLayFmt.
+        GetIDocumentUndoRedo().DoDrawUndo(false);
         pSrcDoc->CopyWithFlyInFly( aRg, 0, aIdx, sal_False, sal_True, sal_True );
+        GetIDocumentUndoRedo().DoDrawUndo(bDrawingLayerUndoState);
     }
     else
     {
@@ -2363,4 +2368,4 @@ std::set<SwRootFrm*> SwDoc::GetAllLayouts()
     return aAllLayouts;
 }//swmod 070825
 
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
\ No newline at end of file
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
