@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,8 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-
-
 #include "hintids.hxx"
 #include <vcl/graph.hxx>
 #include <svx/galbrws.hxx>
@@ -49,15 +48,17 @@
 #include <sfx2/bindings.hxx>
 #include <uivwimp.hxx>
 #include <avmedia/mediaplayer.hxx>
+//#include <swlinguconfig.hxx>
 #include <swmodule.hxx>
 
 #include <sfx2/objface.hxx>
 #include <navipi.hxx>
 #include <wrtsh.hxx>
-#include "doc.hxx"
+#include <edtwin.hxx>
 #include "view.hxx"
 #include "basesh.hxx"
 #include "docsh.hxx"
+#include "doc.hxx"
 #include "globals.hrc"
 #include "cmdid.h"		 	// FN_		 ...
 #include "globdoc.hxx"
@@ -66,11 +67,6 @@
 
 #define OLEObjects
 #define SwView
-#define SearchAttributes
-#define ReplaceAttributes
-#define SearchSettings
-#define _ExecSearch ExecSearch
-#define _StateSearch StateSearch
 #define Frames
 #define Graphics
 #define Tables
@@ -90,11 +86,9 @@
 #define WebListInTable
 #define TextPage
 #include <sfx2/msg.hxx>
-#include <svx/svxslots.hxx>
 #include "swslots.hxx"
 #include <PostItMgr.hxx>
 
-
 using namespace ::com::sun::star;
 using ::rtl::OUString;
 
@@ -104,8 +98,7 @@ using ::rtl::OUString;
 
 #include <unomid.h>
 
-
-SFX_IMPL_VIEWFACTORY(SwView, SW_RES(STR_NONAME))
+SFX_IMPL_NAMED_VIEWFACTORY(SwView, "Default")
 {
     if ( SvtModuleOptions().IsWriter() )
     {
@@ -128,7 +121,6 @@ SFX_IMPL_INTERFACE( SwView, SfxViewShell, SW_RES(RID_TOOLS_TOOLBOX) )
     SFX_CHILDWINDOW_REGISTRATION(FN_INSERT_FIELD_DATA_ONLY);
         SFX_FEATURED_CHILDWINDOW_REGISTRATION(FN_SYNC_LABELS,           CHILDWIN_LABEL    );
         SFX_FEATURED_CHILDWINDOW_REGISTRATION(FN_MAILMERGE_CHILDWINDOW, CHILDWIN_MAILMERGE);
-//    SFX_CHILDWINDOW_REGISTRATION(FN_MAILMERGE_SENDMAIL_CHILDWINDOW);
     SFX_OBJECTBAR_REGISTRATION( SFX_OBJECTBAR_TOOLS|
                                 SFX_VISIBILITY_STANDARD|SFX_VISIBILITY_SERVER,
                                 SW_RES(RID_TOOLS_TOOLBOX) );
@@ -136,24 +128,16 @@ SFX_IMPL_INTERFACE( SwView, SfxViewShell, SW_RES(RID_TOOLS_TOOLBOX) )
 
 TYPEINIT1(SwView,SfxViewShell)
 
-/*-----------------13.12.97 11:06-------------------
-
---------------------------------------------------*/
 ShellModes	SwView::GetShellMode()
 {
     return pViewImpl->GetShellMode();
 }
 
-/*-----------------13.12.97 11:28-------------------
-
---------------------------------------------------*/
 view::XSelectionSupplier* SwView::GetUNOObject()
 {
     return pViewImpl->GetUNOObject();
 }
-/* -----------------------------06.05.2002 13:18------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwView::ApplyAccessiblityOptions(SvtAccessibilityOptions& rAccessibilityOptions)
 {
     pWrtShell->ApplyAccessiblityOptions(rAccessibilityOptions);
@@ -162,39 +146,29 @@ void SwView::ApplyAccessiblityOptions(SvtAccessibilityOptions& rAccessibilityOpt
         pWrtShell->ShowCrsr();
 
 }
-/*-- 26.05.2004 09:14:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void   SwView::SetMailMergeConfigItem(SwMailMergeConfigItem*  pConfigItem,
                 sal_uInt16 nRestart, sal_Bool bIsSource)
 {
     pViewImpl->SetMailMergeConfigItem(pConfigItem, nRestart, bIsSource);
     UIFeatureChanged();
 }
-/*-- 26.05.2004 09:14:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwMailMergeConfigItem*  SwView::GetMailMergeConfigItem()
 {
     return pViewImpl->GetMailMergeConfigItem();
 }
-/*-- 26.05.2004 09:14:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_uInt16 SwView::GetMailMergeRestartPage() const
 {
     return pViewImpl->GetMailMergeRestartPage();
 }
-/*-- 03.09.2004 11:56:33---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool SwView::IsMailMergeSourceView() const
 {
     return pViewImpl->IsMailMergeSourceView();
 }
-/*-- 12.04.2006 11:51:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 sal_Bool lcl_IsViewMarks( const SwViewOption& rVOpt )
 {
     return  rVOpt.IsHardBlank() &&
@@ -206,7 +180,7 @@ void lcl_SetViewMarks(SwViewOption& rVOpt, sal_Bool bOn )
     rVOpt.SetHardBlank(bOn);
     rVOpt.SetSoftHyph(bOn);
     SwViewOption::SetAppearanceFlag(
-            VIEWOPT_FIELD_SHADINGS, bOn, TRUE);
+            VIEWOPT_FIELD_SHADINGS, bOn, sal_True);
 }
 
 void lcl_SetViewMetaChars( SwViewOption& rVOpt, sal_Bool bOn)
@@ -226,6 +200,46 @@ void lcl_SetViewMetaChars( SwViewOption& rVOpt, sal_Bool bOn)
     }
 }
 
+void SwView::RecheckBrowseMode()
+{
+    // OS: numerische Reihenfolge beachten!
+    static sal_uInt16 const aInva[] =
+        {
+            //SID_NEWWINDOW,/*5620*/
+            SID_BROWSER_MODE, /*6313*/
+            SID_RULER_BORDERS, SID_RULER_PAGE_POS,
+            //SID_ATTR_LONG_LRSPACE,
+            SID_HTML_MODE,
+            SID_RULER_PROTECT,
+            //SID_AUTOSPELL_CHECK,
+            //SID_AUTOSPELL_MARKOFF,
+            FN_RULER,      	/*20211*/
+            FN_VIEW_GRAPHIC,    /*20213*/
+            FN_VIEW_BOUNDS,   	/**/
+            FN_VIEW_FIELDS,     /*20215*/
+            FN_VLINEAL,             /*20216*/
+            FN_VSCROLLBAR,      /*20217*/
+            FN_HSCROLLBAR,      /*20218*/
+            FN_VIEW_META_CHARS, /**/
+            FN_VIEW_MARKS,     	/**/
+            //FN_VIEW_FIELDNAME, 	/**/
+            FN_VIEW_TABLEGRID,  /*20227*/
+            FN_PRINT_LAYOUT, /*20237*/
+            FN_QRY_MERGE,   /*20364*/
+            FN_SHADOWCURSOR, /**/
+            0
+        };
+    // the view must not exist!
+    GetViewFrame()->GetBindings().Invalidate(aInva);
+    CheckVisArea();
+
+    SvxZoomType eType;
+    if( GetWrtShell().GetViewOptions()->getBrowseMode() && SVX_ZOOM_PERCENT != (eType = (SvxZoomType)
+        GetWrtShell().GetViewOptions()->GetZoomType()) )
+        SetZoom( eType );
+    InvalidateBorder();
+}
+
 /*--------------------------------------------------------------------
     State of view options
  --------------------------------------------------------------------*/
@@ -240,7 +254,6 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
     while(nWhich)
     {
         sal_Bool bReadonly = GetDocShell()->IsReadOnly();
-        sal_Bool bBrowse = pIDSA ? pIDSA->get( IDocumentSettingAccess::BROWSE_MODE ) : sal_False;
         if ( bReadonly && nWhich != FN_VIEW_GRAPHIC )
         {
             rSet.DisableItem(nWhich);
@@ -250,7 +263,7 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
         {
             case FN_RULER:
             {
-                if(!pOpt->IsViewHRuler(TRUE) && !pOpt->IsViewVRuler(TRUE))
+                if(!pOpt->IsViewHRuler(sal_True) && !pOpt->IsViewVRuler(sal_True))
                 {
                     rSet.DisableItem(nWhich);
                     nWhich = 0;
@@ -259,6 +272,15 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
                     aBool.SetValue( pOpt->IsViewAnyRuler());
             }
             break;
+            case SID_BROWSER_MODE:
+            case FN_PRINT_LAYOUT:
+            {
+                sal_Bool bState = pOpt->getBrowseMode();
+                if(FN_PRINT_LAYOUT == nWhich)
+                    bState = !bState;
+                aBool.SetValue( bState );
+            }
+            break;
             case FN_VIEW_BOUNDS:
                 aBool.SetValue( SwViewOption::IsDocBoundaries()); break;
             case FN_VIEW_GRAPHIC:
@@ -298,7 +320,7 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
             case FN_VLINEAL:
                 aBool.SetValue( 0 != StatVLineal() ); break;
             case FN_HSCROLLBAR:
-                if(bBrowse)
+                if( pOpt->getBrowseMode() )
                 {
                     rSet.DisableItem(nWhich);
                     nWhich = 0;
@@ -311,7 +333,7 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
                 aBool.SetValue( pOpt->IsOnlineSpell() );
             break;
             case FN_SHADOWCURSOR:
-                if (pIDSA == 0 || pIDSA->get( IDocumentSettingAccess::BROWSE_MODE ))
+                if (pIDSA == 0 || pOpt->getBrowseMode() )
                 {
                     rSet.DisableItem( nWhich );
                     nWhich = 0;
@@ -341,6 +363,7 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
 
     int eState = STATE_TOGGLE;
     sal_Bool bSet = sal_False;
+    bool bBrowseModeChanged = false;
 
     const SfxItemSet *pArgs = rReq.GetArgs();
     sal_uInt16 nSlot = rReq.GetSlot();
@@ -352,7 +375,7 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
         eState = bSet ? STATE_ON : STATE_OFF;
     }
 
-    BOOL bFlag = STATE_ON == eState;
+    sal_Bool bFlag = STATE_ON == eState;
     uno::Reference< beans::XPropertySet >  xLngProp( ::GetLinguPropertySet() );
 
     switch ( nSlot )
@@ -367,13 +390,13 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
         case FN_VIEW_FIELDS:
                 if( STATE_TOGGLE == eState )
                     bFlag = !SwViewOption::IsFieldShadings() ;
-                SwViewOption::SetAppearanceFlag(VIEWOPT_FIELD_SHADINGS, bFlag, TRUE );
+                SwViewOption::SetAppearanceFlag(VIEWOPT_FIELD_SHADINGS, bFlag, sal_True );
                 break;
 
         case FN_VIEW_BOUNDS:
                 if( STATE_TOGGLE == eState )
                     bFlag = !SwViewOption::IsDocBoundaries();
-                SwViewOption::SetAppearanceFlag(VIEWOPT_DOC_BOUNDARIES, bFlag, TRUE );
+                SwViewOption::SetAppearanceFlag(VIEWOPT_DOC_BOUNDARIES, bFlag, sal_True );
                 break;
 
         case SID_GRID_VISIBLE:
@@ -397,6 +420,19 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
                 pOpt->SetCrossHair( bFlag );
                 break;
 
+        case SID_BROWSER_MODE:
+        case FN_PRINT_LAYOUT:
+                if( STATE_TOGGLE == eState )
+                    bFlag = !pOpt->getBrowseMode();
+                else if( nSlot == FN_PRINT_LAYOUT )
+                    bFlag = !bFlag;
+                bBrowseModeChanged = bFlag != pOpt->getBrowseMode();
+                // Disable "multiple layout"
+                GetDocShell()->ToggleBrowserMode( bFlag, this );
+                
+                pOpt->setBrowseMode( bFlag );
+                break;
+
     case FN_VIEW_NOTES:
                 if ( STATE_TOGGLE == eState )
                     bFlag = !pOpt->IsPostIts();
@@ -453,7 +489,7 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
         case FN_VIEW_TABLEGRID:
                 if( STATE_TOGGLE == eState )
                     bFlag = !SwViewOption::IsTableBoundaries();
-                SwViewOption::SetAppearanceFlag(VIEWOPT_TABLE_BOUNDARIES, bFlag, TRUE );
+                SwViewOption::SetAppearanceFlag(VIEWOPT_TABLE_BOUNDARIES, bFlag, sal_True );
                 break;
 
         case FN_VIEW_FIELDNAME:
@@ -513,7 +549,7 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
         break;
 
         default:
-            ASSERT(sal_False, Falsche Request-Methode);
+            OSL_FAIL("wrong request method");
             return;
     }
 
@@ -525,6 +561,11 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
     if( !(*rSh.GetViewOptions() == *pOpt ))
     {
         rSh.ApplyViewOptions( *pOpt );
+        if( bBrowseModeChanged )
+        {
+            RecheckBrowseMode();
+            CheckVisArea();
+        }
 
         //Die UsrPref muessen als Modified gekennzeichnet werden.
         //call for initialization
@@ -538,19 +579,21 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
 
     pModule->ApplyUsrPref( *pOpt, this, bWebView ? VIEWOPT_DEST_WEB : VIEWOPT_DEST_TEXT );
 
-    //mod #i6193# let postits know about new spellcheck setting
+    // #i6193# let postits know about new spellcheck setting
     if ( nSlot == SID_AUTOSPELL_CHECK )
         GetPostItMgr()->SetSpellChecking();
 
-    const BOOL bLockedView = rSh.IsViewLocked();
-    rSh.LockView( TRUE );    //lock visible section
+    const sal_Bool bLockedView = rSh.IsViewLocked();
+    rSh.LockView( sal_True );    //lock visible section
     GetWrtShell().EndAction();
+    if( bBrowseModeChanged && !bFlag )
+        CalcVisArea( GetEditWin().GetOutputSizePixel() );
     rSh.LockView( bLockedView );
 
     delete pOpt;
     Invalidate(rReq.GetSlot());
     if(!pArgs)
-        rReq.AppendItem(SfxBoolItem(nSlot, (BOOL)bFlag));
+        rReq.AppendItem(SfxBoolItem(nSlot, (sal_Bool)bFlag));
     rReq.Done();
 }
 
@@ -560,3 +603,5 @@ IMPL_LINK( SwView, HtmlOptionsHdl, void*, EMPTYARG )
     GetViewFrame()->GetBindings().Invalidate(SID_DRAW_TEXT_MARQUEE);
     return 0;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
